#!/bin/bash
#
# this file tests getting the status from an NP1660/1600 printer
# using the SNMP query mechanism
#

# for debugging, uncomment line below
# set -x

usemsg()
{
	echo
	echo "use: $0 printer_ip_addr"
	echo "where: printer_ip_addr = IP Address of NP Printer to query"
	echo
	echo "This utility issues various types of SNMP queries to the"
	echo "specified NP printer, and reports the results.  The queries"
	echo "include Codonics-specific variables, which are defined in"
	echo "accompanying 'mib.txt' file."
	echo
	exit 1
}

# check for unsupported system, but run anyway
SYSTEM=`uname -s`
if [ "$SYSTEM" != "Linux" -a "$SYSTEM" != "SunOS" ]; then
	echo
	echo "Warning: '$SYSTEM' not supported.  Assuming Linux-like OS."
	echo
	SYSTEM=Linux
fi

# handle command line
if [ $# -ne 1 ]; then
	usemsg
fi
PRINTER=$1

# check for printer access with ping
echo "Contacting host..."
if [ "$SYSTEM" = "Linux" ]; then
	ping -c 1 $PRINTER
else
	ping $PRINTER 1
fi
if [ $? -ne 0 ]; then
	echo
	echo "<ERROR>: Host '$PRINTER' is unreachable."
	echo 
	exit 1
fi

# with printer reachable, try SNMP queries -- note that the arguments
# are system-dependent
if [ "$SYSTEM" = "Linux" ]; then
	#export MIBS=`pwd`/mib.txt
	SNMPGET="snmpget -D -v 2p -m `pwd`/mib.txt $PRINTER noAuth"
else
	SNMPGET="snmpget $PRINTER noAuth"
fi

echo 
echo "Getting status from '$PRINTER':"
echo 
echo "****** querying standard SNMP variables ******"

# system variables
# - description
$SNMPGET .1.3.6.1.2.1.1.1.0
# - object id
$SNMPGET .1.3.6.1.2.1.1.2.0
# - up time
$SNMPGET .1.3.6.1.2.1.1.3.0
# - contact
$SNMPGET .1.3.6.1.2.1.1.4.0
# - name
$SNMPGET .1.3.6.1.2.1.1.5.0
# - location
$SNMPGET .1.3.6.1.2.1.1.6.0
# - services
$SNMPGET .1.3.6.1.2.1.1.7.0
# - ORLastChange?
$SNMPGET .1.3.6.1.2.1.1.8.0

# interface variables
# - number
$SNMPGET .1.3.6.1.2.1.2.1.0

# ip variables
# - forwarding?
$SNMPGET .1.3.6.1.2.1.4.1.0

# icmp variables
# - incoming message count
$SNMPGET .1.3.6.1.2.1.5.1.0

# tcp variables
# - max connections
$SNMPGET .1.3.6.1.2.1.6.4.0
# - active opens
$SNMPGET .1.3.6.1.2.1.6.5.0

# udp variables
# - incoming datagram count
$SNMPGET .1.3.6.1.2.1.7.1.0

# egp variables
# - incoming datagram count
$SNMPGET .1.3.6.1.2.1.8.1.0

# snmp variables
# - incoming datagram count
$SNMPGET .1.3.6.1.2.1.11.1.0
# - bad version attempts
$SNMPGET .1.3.6.1.2.1.11.3.0


# old object ID (still used by some applications - ISG)
OCODONICS_OID=100
# new object ID (the official ID)
CODONICS_OID=962

echo 
echo "****** using old OID ($OCODONICS_OID) for 'onp1600' ******"

$SNMPGET .1.3.6.1.4.1.$OCODONICS_OID.1.status.0
$SNMPGET .1.3.6.1.4.1.$OCODONICS_OID.1.ribbon.0
$SNMPGET .1.3.6.1.4.1.$OCODONICS_OID.1.media.0
$SNMPGET .1.3.6.1.4.1.$OCODONICS_OID.1.papersize.0
$SNMPGET .1.3.6.1.4.1.$OCODONICS_OID.1.imageJobs.0
$SNMPGET .1.3.6.1.4.1.$OCODONICS_OID.1.printJobs.0

echo 
echo "****** using new OID ($CODONICS_OID) for 'np1600' *******"

$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.1.status.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.1.ribbon.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.1.media.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.1.papersize.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.1.imageJobs.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.1.printJobs.0

echo 
echo "****** using new OID ($CODONICS_OID) for 'np1660' *******"

$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.2.status.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.2.ribbon.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.2.media.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.2.papersize.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.2.imageJobs.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.2.printJobs.0
$SNMPGET .1.3.6.1.4.1.$CODONICS_OID.2.holdJobs.0

echo 
echo "Done."
echo

